[![GitHub license](https://img.shields.io/github/license/Green-Phys/green-ac?cacheSeconds=3600&color=informational&label=License)](./LICENSE)
[![GitHub license](https://img.shields.io/badge/C%2B%2B-17-blue)](https://en.cppreference.com/w/cpp/compiler_support/17)

![grids](https://github.com/Green-Phys/green-ac/actions/workflows/test.yaml/badge.svg)
[![codecov](https://codecov.io/github/Green-Phys/green-ac/graph/badge.svg?token=MWM2Y2HR8X)](https://codecov.io/github/Green-Phys/green-ac)


# green-ac
Analytical Continuation Tools for Green project


# Acknowledgements

This work is supported by National Science Foundation under the award CSSI-2310582
